@@ -19,13 +19,19 @@ package org.apache.maven.doxia.docrenderer.pdf;
  * under the License.
  */
 
+import java.io.File;
+import java.io.IOException;
+import java.util.Map;
+
 import org.apache.maven.doxia.docrenderer.AbstractDocumentRenderer;
+import org.apache.maven.doxia.docrenderer.DocumentRendererException;
+import org.apache.maven.doxia.document.DocumentModel;
 
 /**
  * Abstract pdf renderer, this doesn't depend on the framework.
  *
  * @author ltheussl
- * @version $Id: AbstractPdfRenderer.java 746998 2009-02-23 12:52:18Z vsiveton $
+ * @version $Id: AbstractPdfRenderer.java 809520 2009-08-31 09:33:52Z vsiveton $
  * @since 1.1
  */
 public abstract class AbstractPdfRenderer
@@ -37,4 +43,11 @@ public abstract class AbstractPdfRenderer
     {
         return "pdf";
     }
+
+    /** {@inheritDoc} */
+    public void render( Map filesToProcess, File outputDirectory, DocumentModel documentModel )
+        throws DocumentRendererException, IOException
+    {
+        render( filesToProcess, outputDirectory, documentModel, null );
+    }
 }
