@@ -47,6 +47,7 @@ import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamResult;
 import javax.xml.transform.stream.StreamSource;
 
+import org.apache.maven.doxia.docrenderer.DocumentRendererContext;
 import org.apache.maven.doxia.docrenderer.DocumentRendererException;
 import org.apache.maven.doxia.docrenderer.pdf.AbstractPdfRenderer;
 import org.apache.maven.doxia.document.DocumentCover;
@@ -73,7 +74,7 @@ import com.lowagie.text.ElementTags;
  *
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
  * @author ltheussl
- * @version $Id: ITextPdfRenderer.java 784080 2009-06-12 11:22:38Z vsiveton $
+ * @version $Id: ITextPdfRenderer.java 811653 2009-09-05 14:19:51Z vsiveton $
  * @since 1.1
  * @plexus.component role="org.apache.maven.doxia.docrenderer.pdf.PdfRenderer" role-hint="itext"
  */
@@ -132,6 +133,13 @@ public class ITextPdfRenderer
     /** {@inheritDoc} */
     public void render( Map filesToProcess, File outputDirectory, DocumentModel documentModel )
         throws DocumentRendererException, IOException
+    {
+        render( filesToProcess, outputDirectory, documentModel, null );
+    }
+
+    /** {@inheritDoc} */
+    public void render( Map filesToProcess, File outputDirectory, DocumentModel documentModel, DocumentRendererContext context )
+        throws DocumentRendererException, IOException
     {
         // copy resources, images, etc.
         copyResources( outputDirectory );
@@ -140,7 +148,7 @@ public class ITextPdfRenderer
         {
             getLogger().debug( "No document model, generating all documents individually." );
 
-            renderIndividual( filesToProcess, outputDirectory );
+            renderIndividual( filesToProcess, outputDirectory, context );
             return;
         }
 
@@ -163,25 +171,36 @@ public class ITextPdfRenderer
         {
             getLogger().info( "No TOC is defined in the document descriptor. Merging all documents." );
 
-            iTextFiles = parseAllFiles( filesToProcess, outputDirectory );
+            iTextFiles = parseAllFiles( filesToProcess, outputDirectory, context );
         }
         else
         {
             getLogger().debug( "Using TOC defined in the document descriptor." );
 
-            iTextFiles = parseTOCFiles( filesToProcess, outputDirectory, documentModel );
+            iTextFiles = parseTOCFiles( outputDirectory, documentModel, context );
         }
 
+        String generateTOC =
+            ( context != null && context.get( "generateTOC" ) != null ? context.get( "generateTOC" ).toString()
+                            : "start" );
+
         File iTextFile = new File( outputDirectory, outputName + ".xml" );
         File iTextOutput = new File( outputDirectory, outputName + "." + getOutputExtension() );
         Document document = generateDocument( iTextFiles );
-        transform( documentModel, document, iTextFile );
+        transform( documentModel, document, iTextFile, generateTOC );
         generatePdf( iTextFile, iTextOutput );
     }
 
     /** {@inheritDoc} */
     public void renderIndividual( Map filesToProcess, File outputDirectory )
         throws DocumentRendererException, IOException
+    {
+        renderIndividual( filesToProcess, outputDirectory, null );
+    }
+
+    /** {@inheritDoc} */
+    public void renderIndividual( Map filesToProcess, File outputDirectory, DocumentRendererContext context )
+        throws DocumentRendererException, IOException
     {
         for ( Iterator it = filesToProcess.keySet().iterator(); it.hasNext(); )
         {
@@ -209,7 +228,7 @@ public class ITextPdfRenderer
                 pdfOutputFile.getParentFile().mkdirs();
             }
 
-            parse( fullDoc, module, outputITextFile );
+            parse( fullDoc, module, outputITextFile, context );
 
             generatePdf( outputITextFile, pdfOutputFile );
         }
@@ -229,7 +248,7 @@ public class ITextPdfRenderer
      * @throws DocumentRendererException in case of a parsing problem.
      * @throws IOException if the source and/or target document cannot be opened.
      */
-    private void parse( File fullDoc, SiteModule module, File iTextFile )
+    private void parse( File fullDoc, SiteModule module, File iTextFile, DocumentRendererContext context )
         throws DocumentRendererException, IOException
     {
         if ( getLogger().isDebugEnabled() )
@@ -248,7 +267,7 @@ public class ITextPdfRenderer
 
             sink.setClassLoader( new URLClassLoader( new URL[] { iTextFile.getParentFile().toURI().toURL() } ) );
 
-            parse( fullDoc.getAbsolutePath(), module.getParserId(), sink );
+            parse( fullDoc.getAbsolutePath(), module.getParserId(), sink, context );
         }
         finally
         {
@@ -354,14 +373,19 @@ public class ITextPdfRenderer
      * @param transformer the Transformer to set the parameters.
      * @param documentModel the DocumentModel to take the parameters from, could be null.
      * @param iTextFile the iTextFile not null for the relative paths.
+     * @param generateTOC not null, possible values are: 'none', 'start' and 'end'.
      */
-    private void addTransformerParameters( Transformer transformer, DocumentModel documentModel, File iTextFile )
+    private void addTransformerParameters( Transformer transformer, DocumentModel documentModel, File iTextFile,
+                                           String generateTOC )
     {
         if ( documentModel == null )
         {
             return;
         }
 
+        // TOC
+        addTransformerParameter( transformer, "toc.position", generateTOC );
+
         // Meta parameters
         boolean hasNullMeta = false;
         if ( documentModel.getMeta() == null )
@@ -467,22 +491,38 @@ public class ITextPdfRenderer
      * @param documentModel the DocumentModel to take the parameters from, could be null.
      * @param document the Document to transform.
      * @param iTextFile the resulting iText xml file.
+     * @param generateTOC not null, possible values are: 'none', 'start' and 'end'.
      * @throws DocumentRendererException in case of a transformation error.
      */
-    private void transform( DocumentModel documentModel, Document document, File iTextFile )
+    private void transform( DocumentModel documentModel, Document document, File iTextFile, String generateTOC )
         throws DocumentRendererException
     {
         Transformer transformer = initTransformer();
 
-        addTransformerParameters( transformer, documentModel, iTextFile );
+        addTransformerParameters( transformer, documentModel, iTextFile, generateTOC );
 
+        // need a writer for StreamResult to prevent FileNotFoundException when iTextFile contains spaces
+        Writer writer = null;
         try
         {
-            transformer.transform( new DOMSource( document ), new StreamResult( iTextFile ) );
+            writer = WriterFactory.newXmlWriter( iTextFile );
+            transformer.transform( new DOMSource( document ), new StreamResult( writer ) );
         }
         catch ( TransformerException e )
         {
-            throw new DocumentRendererException( "Error transforming Document " + document + ": " + e.getMessage() );
+            throw new DocumentRendererException(
+                                                 "Error transforming Document " + document + ": " + e.getMessage(),
+                                                 e );
+        }
+        catch ( IOException e )
+        {
+            throw new DocumentRendererException(
+                                                 "Error transforming Document " + document + ": " + e.getMessage(),
+                                                 e );
+        }
+        finally
+        {
+            IOUtil.close( writer );
         }
     }
 
@@ -494,7 +534,7 @@ public class ITextPdfRenderer
      * @throws IOException if any
      * @since 1.1.1
      */
-    private List parseAllFiles( Map filesToProcess, File outputDirectory )
+    private List parseAllFiles( Map filesToProcess, File outputDirectory, DocumentRendererContext context )
         throws DocumentRendererException, IOException
     {
         List iTextFiles = new LinkedList();
@@ -513,7 +553,7 @@ public class ITextPdfRenderer
             }
 
             iTextFiles.add( outputITextFileTmp );
-            parse( fullDoc, module, outputITextFileTmp );
+            parse( fullDoc, module, outputITextFileTmp, context );
         }
 
         return iTextFiles;
@@ -527,7 +567,7 @@ public class ITextPdfRenderer
      * @throws IOException if any
      * @since 1.1.1
      */
-    private List parseTOCFiles( Map filesToProcess, File outputDirectory, DocumentModel documentModel )
+    private List parseTOCFiles( File outputDirectory, DocumentModel documentModel, DocumentRendererContext context )
         throws DocumentRendererException, IOException
     {
         List iTextFiles = new LinkedList();
@@ -559,6 +599,20 @@ public class ITextPdfRenderer
                     String doc = href + "." + module.getExtension();
                     File source = new File( moduleBasedir, doc );
 
+                    // Velocity file?
+                    if ( !source.exists() )
+                    {
+                        if ( href.indexOf( "." + module.getExtension() ) != -1 )
+                        {
+                            doc = href + ".vm";
+                        }
+                        else
+                        {
+                            doc = href + "." + module.getExtension() + ".vm";
+                        }
+                        source = new File( moduleBasedir, doc );
+                    }
+
                     if ( source.exists() )
                     {
                         String outputITextName = doc.substring( 0, doc.lastIndexOf( "." ) + 1 ) + "xml";
@@ -570,7 +624,7 @@ public class ITextPdfRenderer
                         }
 
                         iTextFiles.add( outputITextFileTmp );
-                        parse( source, module, outputITextFileTmp );
+                        parse( source, module, outputITextFileTmp, context );
                     }
                 }
             }
@@ -607,12 +661,12 @@ public class ITextPdfRenderer
                 }
                 else
                 {
-                    return f.toURL().toString();
+                    return f.toURI().toURL().toString();
                 }
             }
             catch ( MalformedURLException e1 )
             {
-                // nope
+                getLogger().debug( "Failed to convert to URL: " + logo, e1 );
             }
         }
 
