@@ -19,6 +19,7 @@ package org.apache.maven.doxia.siterenderer;
  * under the License.
  */
 
+import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
@@ -63,6 +64,7 @@ import org.apache.maven.doxia.module.site.SiteModule;
 import org.apache.maven.doxia.module.site.manager.SiteModuleManager;
 import org.apache.maven.doxia.module.site.manager.SiteModuleNotFoundException;
 import org.apache.maven.doxia.siterenderer.sink.SiteRendererSink;
+import org.apache.maven.doxia.util.XmlValidator;
 
 import org.apache.velocity.Template;
 import org.apache.velocity.VelocityContext;
@@ -87,7 +89,7 @@ import org.codehaus.plexus.velocity.VelocityComponent;
  *
  * @author <a href="mailto:evenisse@codehaus.org">Emmanuel Venisse</a>
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
- * @version $Id: DefaultSiteRenderer.java 772924 2009-05-08 10:22:12Z vsiveton $
+ * @version $Id: DefaultSiteRenderer.java 943453 2010-05-12 11:35:48Z ltheussl $
  * @since 1.0
  * @plexus.component role-hint="default"
  */
@@ -99,9 +101,7 @@ public class DefaultSiteRenderer
     // Requirements
     // ----------------------------------------------------------------------
 
-    /**
-     * @plexus.requirement
-     */
+    /** @plexus.requirement */
     private VelocityComponent velocity;
 
     /**
@@ -109,14 +109,10 @@ public class DefaultSiteRenderer
      */
     private SiteModuleManager siteModuleManager;
 
-    /**
-     * @plexus.requirement
-     */
+    /** @plexus.requirement */
     private Doxia doxia;
 
-    /**
-     * @plexus.requirement
-     */
+    /** @plexus.requirement */
     private I18N i18n;
 
     private static final String RESOURCE_DIR = "org/apache/maven/doxia/siterenderer/resources";
@@ -312,11 +308,8 @@ public class DefaultSiteRenderer
 
             File inputFile = new File( renderingContext.getBasedir(), renderingContext.getInputName() );
 
-            boolean modified = false;
-            if ( !outputFile.exists() || inputFile.lastModified() > outputFile.lastModified() )
-            {
-                modified = true;
-            }
+            boolean modified = !outputFile.exists() || ( inputFile.lastModified() > outputFile.lastModified() )
+                || ( siteRenderingContext.getDecoration().getLastModified() > outputFile.lastModified() );
 
             if ( modified || docRenderer.isOverwrite() )
             {
@@ -364,13 +357,13 @@ public class DefaultSiteRenderer
         Reader reader = null;
         try
         {
+            String resource = doc.getAbsolutePath();
+
             Parser parser = doxia.getParser( renderingContext.getParserId() );
 
             // TODO: DOXIA-111: the filter used here must be checked generally.
             if ( renderingContext.getAttribute( "velocity" ) != null )
             {
-                String resource = doc.getAbsolutePath();
-
                 try
                 {
                     SiteResourceLoader.setResource( resource );
@@ -401,6 +394,10 @@ public class DefaultSiteRenderer
                 {
                     case Parser.XML_TYPE:
                         reader = ReaderFactory.newXmlReader( doc );
+                        if ( context.isValidate() )
+                        {
+                            reader = validate( reader, resource );
+                        }
                         break;
 
                     case Parser.TXT_TYPE:
@@ -482,11 +479,12 @@ public class DefaultSiteRenderer
             try
             {
                 // we support only ISO-8601 date
-                context.put( "dateCreation", sdf.format( new SimpleDateFormat( "yyyy-MM-dd" ).parse( sink.getDate() ) ) );
+                context.put( "dateCreation",
+                        sdf.format( new SimpleDateFormat( "yyyy-MM-dd" ).parse( sink.getDate() ) ) );
             }
-            catch ( Exception e )
+            catch ( java.text.ParseException e )
             {
-                // nop
+                getLogger().debug( "Could not parse date: " + sink.getDate() + ", ignoring!", e );
             }
         }
         context.put( "dateRevision", sdf.format( new Date() ) );
@@ -869,4 +867,23 @@ public class DefaultSiteRenderer
         }
     }
 
+    private Reader validate( Reader source, String resource )
+            throws ParseException, IOException
+    {
+        getLogger().debug( "Validating: " + resource );
+
+        try
+        {
+            String content = IOUtil.toString( new BufferedReader( source ) );
+
+            new XmlValidator( new PlexusLoggerWrapper( getLogger() ) ).validate( content );
+
+            return new StringReader( content );
+        }
+        finally
+        {
+            IOUtil.close( source );
+        }
+    }
+
 }
