@@ -46,7 +46,7 @@ import org.codehaus.plexus.util.StringUtils;
 /**
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
  * @author <a href="mailto:evenisse@codehaus.org>Emmanuel Venisse</a>
- * @version $Id: DefaultSiteRendererTest.java 809114 2009-08-29 11:14:06Z vsiveton $
+ * @version $Id: DefaultSiteRendererTest.java 943453 2010-05-12 11:35:48Z ltheussl $
  */
 public class DefaultSiteRendererTest
     extends PlexusTestCase
@@ -124,16 +124,11 @@ public class DefaultSiteRendererTest
         DecorationModel decoration = new DecorationXpp3Reader()
             .read( new FileReader( getTestFile( "src/test/resources/site/site.xml" ) ) );
 
-        SiteRenderingContext ctxt = new SiteRenderingContext();
-        ctxt.setTemplateName( "default-site.vm" );
-        ctxt.setTemplateClassLoader( getClassLoader() );
-        ctxt.setUsingDefaultTemplate( true );
-        Map templateProp = new HashMap();
-        templateProp.put( "outputEncoding", "UTF-8" );
-        ctxt.setTemplateProperties( templateProp );
-        ctxt.setDecoration( decoration );
-        ctxt.addSiteDirectory( getTestFile( "src/test/resources/site" ) );
+        SiteRenderingContext ctxt = getSiteRenderingContext(
+                decoration, "src/test/resources/site", false );
+        renderer.render( renderer.locateDocumentFiles( ctxt ).values(), ctxt, getTestFile( OUTPUT ) );
 
+        ctxt = getSiteRenderingContext( decoration, "src/test/resources/site-validate", true );
         renderer.render( renderer.locateDocumentFiles( ctxt ).values(), ctxt, getTestFile( OUTPUT ) );
 
         // ----------------------------------------------------------------------
@@ -158,6 +153,22 @@ public class DefaultSiteRendererTest
         validatePages();
     }
 
+    private SiteRenderingContext getSiteRenderingContext( DecorationModel decoration, String siteDir, boolean validate )
+    {
+        SiteRenderingContext ctxt = new SiteRenderingContext();
+        ctxt.setTemplateName( "default-site.vm" );
+        ctxt.setTemplateClassLoader( getClassLoader() );
+        ctxt.setUsingDefaultTemplate( true );
+        Map templateProp = new HashMap();
+        templateProp.put( "outputEncoding", "UTF-8" );
+        ctxt.setTemplateProperties( templateProp );
+        ctxt.setDecoration( decoration );
+        ctxt.addSiteDirectory( getTestFile( siteDir ) );
+        ctxt.setValidate( validate );
+
+        return ctxt;
+    }
+
     /**
      * @throws Exception if something goes wrong.
      */
